@@ -23,6 +23,7 @@ import six
 
 from ironic_python_agent import encoding
 from ironic_python_agent import errors
+from ironic_python_agent import utils
 
 
 LOG = log.getLogger()
@@ -60,9 +61,10 @@ class BaseCommandResult(encoding.SerializableComparable):
         return ("Command name: %(name)s, "
                 "params: %(params)s, status: %(status)s, result: "
                 "%(result)s." %
-                {"name": self.command_name, "params": self.command_params,
+                {"name": self.command_name,
+                 "params": utils.remove_large_keys(self.command_params),
                  "status": self.command_status,
-                 "result": self.command_result})
+                 "result": utils.remove_large_keys(self.command_result)})
 
     def is_done(self):
         """Checks to see if command is still RUNNING.
@@ -161,8 +163,9 @@ class AsyncCommandResult(BaseCommandResult):
 
             if isinstance(result, (bytes, six.text_type)):
                 result = {'result': '{}: {}'.format(self.command_name, result)}
-            LOG.info('Command: %(name)s, result: %(result)s',
-                     {'name': self.command_name, 'result': result})
+            LOG.info('Asynchronous command %(name)s completed: %(result)s',
+                     {'name': self.command_name,
+                      'result': utils.remove_large_keys(result)})
             with self.command_state_lock:
                 self.command_result = result
                 self.command_status = AgentCommandStatus.SUCCEEDED
@@ -236,7 +239,8 @@ class ExecuteCommandMixin(object):
         """Execute an agent command."""
         with self.command_lock:
             LOG.debug('Executing command: %(name)s with args: %(args)s',
-                      {'name': command_name, 'args': kwargs})
+                      {'name': command_name,
+                       'args': utils.remove_large_keys(kwargs)})
             extension_part, command_part = self.split_command(command_name)
 
             if len(self.command_results) > 0:
@@ -265,8 +269,6 @@ class ExecuteCommandMixin(object):
                 # recorded as a failed SyncCommandResult with an error message
                 LOG.exception('Command execution error: %s', e)
                 result = SyncCommandResult(command_name, kwargs, False, e)
-            LOG.info('Command %(name)s completed: %(result)s',
-                     {'name': command_name, 'result': result})
             self.command_results[result.id] = result
             return result
 
@@ -293,10 +295,13 @@ def async_command(command_name, validator=None):
             # know about the mode
             bound_func = functools.partial(func, self)
 
-            return AsyncCommandResult(command_name,
-                                      command_params,
-                                      bound_func,
-                                      agent=self.agent).start()
+            ret = AsyncCommandResult(command_name,
+                                     command_params,
+                                     bound_func,
+                                     agent=self.agent).start()
+            LOG.info('Asynchronous command %(name)s started execution',
+                     {'name': command_name})
+            return ret
         return wrapper
     return async_decorator
 
@@ -319,6 +324,9 @@ def sync_command(command_name, validator=None):
                 validator(self, **command_params)
 
             result = func(self, **command_params)
+            LOG.info('Synchronous command %(name)s completed: %(result)s',
+                     {'name': command_name,
+                      'result': utils.remove_large_keys(result)})
             return SyncCommandResult(command_name,
                                      command_params,
                                      True,
