@@ -14,6 +14,7 @@
 
 import os
 import tempfile
+import time
 
 import mock
 from oslo_concurrency import processutils
@@ -398,6 +399,7 @@ class TestStandbyExtension(base.IronicAgentTest):
 
     @mock.patch('requests.get', autospec=True)
     def test_download_image_bad_status(self, requests_mock):
+        self.config(image_download_connection_retry_interval=0)
         image_info = _build_fake_image_info()
         response = requests_mock.return_value
         response.status_code = 404
@@ -1078,6 +1080,8 @@ class TestStandbyExtension(base.IronicAgentTest):
     @mock.patch('requests.get', autospec=True)
     def test_stream_raw_image_onto_device_write_error(self, requests_mock,
                                                       open_mock, md5_mock):
+        self.config(image_download_connection_timeout=1)
+        self.config(image_download_connection_retry_interval=0)
         image_info = _build_fake_image_info()
         response = requests_mock.return_value
         response.status_code = 200
@@ -1091,12 +1095,20 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertRaises(errors.ImageDownloadError,
                           self.agent_extension._stream_raw_image_onto_device,
                           image_info, '/dev/foo')
-        requests_mock.assert_called_once_with(image_info['urls'][0],
-                                              cert=None, verify=True,
-                                              stream=True, proxies={},
-                                              timeout=60)
-        # Assert write was only called once and failed!
-        file_mock.write.assert_called_once_with('some')
+        calls = [mock.call('http://example.org', cert=None, proxies={},
+                           stream=True, timeout=1, verify=True),
+                 mock.call().iter_content(mock.ANY),
+                 mock.call('http://example.org', cert=None, proxies={},
+                           stream=True, timeout=1, verify=True),
+                 mock.call().iter_content(mock.ANY),
+                 mock.call('http://example.org', cert=None, proxies={},
+                           stream=True, timeout=1, verify=True),
+                 mock.call().iter_content(mock.ANY)]
+        requests_mock.assert_has_calls(calls)
+        write_calls = [mock.call('some'),
+                       mock.call('some'),
+                       mock.call('some')]
+        file_mock.write.assert_has_calls(write_calls)
 
     @mock.patch('ironic_lib.disk_utils.get_disk_identifier',
                 lambda dev: 'ROOT')
@@ -1111,6 +1123,71 @@ class TestStandbyExtension(base.IronicAgentTest):
                         '/dev/fake root_uuid=ROOT')
         self.assertEqual(expected_msg, result_msg)
 
+    @mock.patch('ironic_lib.disk_utils.fix_gpt_partition', autospec=True)
+    @mock.patch('hashlib.md5', autospec=True)
+    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('requests.get', autospec=True)
+    def test_stream_raw_image_onto_device_socket_read_timeout(
+            self, requests_mock, open_mock, md5_mock, fix_gpt_mock):
+
+        class create_timeout(object):
+            status_code = 200
+
+            def __init__(self, url, stream, proxies, verify, cert, timeout):
+                time.sleep(1)
+                self.count = 0
+
+            def __iter__(self):
+                return self
+
+            def __next__(self):
+                if self.count:
+                    time.sleep(0.1)
+                    return None
+                if self.count < 3:
+                    self.count += 1
+                    return "meow"
+                else:
+                    time.sleep(30)
+                    raise StopIteration
+
+            # Python 2
+            next = __next__
+
+            def iter_content(self, chunk_size):
+                return self
+
+        self.config(image_download_connection_timeout=1)
+        self.config(image_download_connection_retries=2)
+        self.config(image_download_connection_retry_interval=0)
+        image_info = _build_fake_image_info()
+        file_mock = mock.Mock()
+        open_mock.return_value.__enter__.return_value = file_mock
+        file_mock.read.return_value = None
+        hexdigest_mock = md5_mock.return_value.hexdigest
+        hexdigest_mock.return_value = image_info['checksum']
+        requests_mock.side_effect = create_timeout
+        self.assertRaisesRegex(
+            errors.ImageDownloadError,
+            'Timed out reading next chunk',
+            self.agent_extension._stream_raw_image_onto_device,
+            image_info,
+            '/dev/foo')
+
+        calls = [mock.call(image_info['urls'][0], cert=None, verify=True,
+                           stream=True, proxies={}, timeout=1),
+                 mock.call(image_info['urls'][0], cert=None, verify=True,
+                           stream=True, proxies={}, timeout=1),
+                 mock.call(image_info['urls'][0], cert=None, verify=True,
+                           stream=True, proxies={}, timeout=1)]
+        requests_mock.assert_has_calls(calls)
+
+        write_calls = [mock.call('meow'),
+                       mock.call('meow'),
+                       mock.call('meow')]
+        file_mock.write.assert_has_calls(write_calls)
+        self.assertFalse(fix_gpt_mock.called)
+
     def test__message_format_partition_bios(self):
         image_info = _build_fake_partition_image_info()
         msg = ('image ({}) already present on device {} ')
@@ -1212,6 +1289,7 @@ class TestImageDownload(base.IronicAgentTest):
     @mock.patch('time.sleep', autospec=True)
     def test_download_image_retries(self, sleep_mock, requests_mock,
                                     time_mock):
+        self.config(image_download_connection_retries=2)
         response = requests_mock.return_value
         response.status_code = 500
         response.text = 'Oops'
@@ -1228,7 +1306,7 @@ class TestImageDownload(base.IronicAgentTest):
                                          stream=True, proxies={},
                                          timeout=60)
         self.assertEqual(3, requests_mock.call_count)
-        sleep_mock.assert_called_with(5)
+        sleep_mock.assert_called_with(10)
         self.assertEqual(2, sleep_mock.call_count)
 
     @mock.patch('time.sleep', autospec=True)
@@ -1253,7 +1331,7 @@ class TestImageDownload(base.IronicAgentTest):
                                          stream=True, proxies={},
                                          timeout=60)
         self.assertEqual(3, requests_mock.call_count)
-        sleep_mock.assert_called_with(5)
+        sleep_mock.assert_called_with(10)
         self.assertEqual(2, sleep_mock.call_count)
 
     def test_download_image_and_checksum(self, requests_mock, md5_mock):
@@ -1353,6 +1431,7 @@ foobar  irrelevant file.img
                                standby.ImageDownload, image_info)
 
     def test_download_image_and_checksum_failed(self, requests_mock, md5_mock):
+        self.config(image_download_connection_retry_interval=0)
         content = ['SpongeBob', 'SquarePants']
         cs_response = mock.Mock()
         cs_response.status_code = 400
